==> dbmanager-oracle-1.2.3-sources.jar: com/lutris/appserver/server/sql/oracle/OracleDriverDependencies.java <==

package com.lutris.appserver.server.sql.oracle;

import java.io.*;
import java.sql.*;

import com.lutris.appserver.server.sql.DBConnection;
import com.lutris.dods.builder.generator.query.RDBColumn;
import oracle.jdbc.OracleResultSet;
import oracle.sql.BLOB;
import org.enhydra.dods.DriverDependencies;

/**
 *
 */
public class OracleDriverDependencies implements DriverDependencies {

    public boolean isBlobAccessSpecial() {
        return true;
    }

    public void insertBlob(DBConnection conn, byte[] cont, RDBColumn primary, RDBColumn column, String  handle) throws SQLException {
        if (null == cont) return;
        PreparedStatement qb = null;
        PreparedStatement pp = null;
        ResultSet rs = null;
        BLOB blob = null;
        InputStream in = null;
        OutputStream out = null;
        try {
            qb = conn.getConnection()
                .prepareStatement("select "
                                  + column.getColumnName()
                                  +" from "
                                  + column.getTableName()
                                  + " where "
                                  + primary.getColumnName()
                                  + " = "
                                  + handle
                                  + " FOR UPDATE");
            rs = qb.executeQuery();
            rs.next();
            blob = ((OracleResultSet)rs).getBLOB(1);

            in = new BufferedInputStream(new ByteArrayInputStream(cont));
            out = blob.getBinaryOutputStream();
            int chunk = blob.getChunkSize();
            byte[] buffer = new byte[chunk];
            int length = -1;

            while ((length = in.read(buffer)) != -1) {
                out.write ( buffer, 0, length );
            }
            if (blob.length() != cont.length)
                out.flush();
        } catch (IOException e) {
            throw new SQLException("tweak failure",e.getMessage());
        } finally {
            try {
                if (out != null) out.close();
                if (in != null) in.close();
                if (rs != null) rs.close();
                if (qb != null) qb.close();
                if (pp != null) pp.close();
            } catch (Exception  e2) {}
        }
    }

    public byte[] readBlob(ResultSet rs, String  colName) throws SQLException {
        BLOB blob = ((OracleResultSet)rs).getBLOB(colName);
        if (null == blob) return null;
        return blob.getBytes(1L, (int)blob.length());
    }
}

==> dbmanager-oracle-1.3.12-sources.jar: com/lutris/appserver/server/sql/oracle/OracleDriverDependencies.java <==

package com.lutris.appserver.server.sql.oracle;

import java.io.*;
import java.sql.*;

import com.lutris.appserver.server.sql.DBConnection;
import com.lutris.dods.builder.generator.query.RDBColumn;
import oracle.jdbc.OracleResultSet;
import oracle.sql.BLOB;
import org.enhydra.dods.DriverDependencies;

/**
 *
 */
public class OracleDriverDependencies implements DriverDependencies {

    public boolean isBlobAccessSpecial() {
        return true;
    }

    public void insertBlob(DBConnection conn, byte[] cont, RDBColumn primary, RDBColumn column, String  handle) throws SQLException {
        if (null == cont) return;
        PreparedStatement qb = null;
        PreparedStatement pp = null;
        ResultSet rs = null;
        BLOB blob = null;
        InputStream in = null;
        OutputStream out = null;
        try {
            qb = conn.getConnection()
                .prepareStatement("select "
                                  + column.getColumnName()
                                  +" from "
                                  + column.getTableName()
                                  + " where "
                                  + primary.getColumnName()
                                  + " = "
                                  + handle
                                  + " FOR UPDATE");
            rs = qb.executeQuery();
            rs.next();

            // getBlob(...) deleguje odpowiednio metodę do OracleResultSet#getBLOB(...)
            blob = (BLOB) rs.getBlob( 1 );

            in = new BufferedInputStream(new ByteArrayInputStream(cont));
            out = blob.getBinaryOutputStream();
            int chunk = blob.getChunkSize();
            byte[] buffer = new byte[chunk];
            int length = -1;

            while ((length = in.read(buffer)) != -1) {
                out.write ( buffer, 0, length );
            }
            if (blob.length() != cont.length)
                out.flush();
        } catch (IOException e) {
            throw new SQLException("tweak failure",e.getMessage());
        } finally {
            try {
                if (out != null) out.close();
                if (in != null) in.close();
                if (rs != null) rs.close();
                if (qb != null) qb.close();
                if (pp != null) pp.close();
            } catch (Exception  e2) {}
        }
    }

    public byte[] readBlob(ResultSet rs, String  colName) throws SQLException {
        // getBlob(...) deleguje odpowiednio metodę do OracleResultSet#getBLOB(...)
        BLOB blob = (BLOB) rs.getBlob( colName );
        if (null == blob) return null;
        return blob.getBytes(1L, (int)blob.length());
    }
}
